@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.metastore_v1alpha.types import metastore
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
 
 
@@ -74,7 +71,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
         self,
         *,
         host: str = "metastore.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -88,7 +85,8 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -130,7 +128,10 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
+        self._stubs: Dict[str, Callable] = {}
+        self._operations_client = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -138,95 +139,65 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             warnings.warn("client_cert_source is deprecated", DeprecationWarning)
 
         if channel:
-            # Sanity check: Ensure that channel and credentials are not both
-            # provided.
+            # Ignore credentials if a channel was passed.
             credentials = False
-
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-        elif api_mtls_endpoint:
-            host = (
-                api_mtls_endpoint
-                if ":" in api_mtls_endpoint
-                else api_mtls_endpoint + ":443"
-            )
 
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
-
-            # Create SSL credentials with client_cert_source or application
-            # default SSL credentials.
-            if client_cert_source:
-                cert, key = client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
-            else:
-                ssl_credentials = SslCredentials().ssl_credentials
-
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=ssl_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
-            self._ssl_channel_credentials = ssl_credentials
         else:
-            host = host if ":" in host else host + ":443"
+            if api_mtls_endpoint:
+                host = api_mtls_endpoint
 
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
+                # Create SSL credentials with client_cert_source or application
+                # default SSL credentials.
+                if client_cert_source:
+                    cert, key = client_cert_source()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
+                else:
+                    self._ssl_channel_credentials = SslCredentials().ssl_credentials
 
-            if client_cert_source_for_mtls and not ssl_channel_credentials:
-                cert, key = client_cert_source_for_mtls()
-                self._ssl_channel_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
+            else:
+                if client_cert_source_for_mtls and not ssl_channel_credentials:
+                    cert, key = client_cert_source_for_mtls()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
 
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=self._ssl_channel_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
-
-        self._stubs = {}  # type: Dict[str, Callable]
-        self._operations_client = None
-
-        # Run the base constructor.
+        # The base transport sets the host, credentials and scopes
         super().__init__(
             host=host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes or self.AUTH_SCOPES,
+            scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
         )
 
+        if not self._grpc_channel:
+            self._grpc_channel = type(self).create_channel(
+                self._host,
+                credentials=self._credentials,
+                credentials_file=credentials_file,
+                scopes=self._scopes,
+                ssl_credentials=self._ssl_channel_credentials,
+                quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
+            )
+
+        # Wrap messages. This must be done after self._grpc_channel exists
+        self._prep_wrapped_messages(client_info)
+
     @classmethod
     def create_channel(
         cls,
         host: str = "metastore.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -234,7 +205,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     ) -> grpc.Channel:
         """Create and return a gRPC channel object.
         Args:
-            address (Optional[str]): The host for the channel to use.
+            host (Optional[str]): The host for the channel to use.
             credentials (Optional[~.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify this application to the service. If
@@ -257,13 +228,15 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -340,7 +313,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     @property
     def create_service(
         self,
-    ) -> Callable[[metastore.CreateServiceRequest], operations.Operation]:
+    ) -> Callable[[metastore.CreateServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the create service method over gRPC.
 
         Creates a metastore service in a project and
@@ -360,14 +333,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["create_service"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/CreateService",
                 request_serializer=metastore.CreateServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_service"]
 
     @property
     def update_service(
         self,
-    ) -> Callable[[metastore.UpdateServiceRequest], operations.Operation]:
+    ) -> Callable[[metastore.UpdateServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the update service method over gRPC.
 
         Updates the parameters of a single service.
@@ -386,14 +359,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["update_service"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/UpdateService",
                 request_serializer=metastore.UpdateServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_service"]
 
     @property
     def delete_service(
         self,
-    ) -> Callable[[metastore.DeleteServiceRequest], operations.Operation]:
+    ) -> Callable[[metastore.DeleteServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete service method over gRPC.
 
         Deletes a single service.
@@ -412,7 +385,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["delete_service"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/DeleteService",
                 request_serializer=metastore.DeleteServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_service"]
 
@@ -473,7 +446,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     @property
     def create_metadata_import(
         self,
-    ) -> Callable[[metastore.CreateMetadataImportRequest], operations.Operation]:
+    ) -> Callable[[metastore.CreateMetadataImportRequest], operations_pb2.Operation]:
         r"""Return a callable for the create metadata import method over gRPC.
 
         Creates a new MetadataImport in a given project and
@@ -493,14 +466,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["create_metadata_import"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/CreateMetadataImport",
                 request_serializer=metastore.CreateMetadataImportRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_metadata_import"]
 
     @property
     def update_metadata_import(
         self,
-    ) -> Callable[[metastore.UpdateMetadataImportRequest], operations.Operation]:
+    ) -> Callable[[metastore.UpdateMetadataImportRequest], operations_pb2.Operation]:
         r"""Return a callable for the update metadata import method over gRPC.
 
         Updates a single import.
@@ -521,14 +494,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["update_metadata_import"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/UpdateMetadataImport",
                 request_serializer=metastore.UpdateMetadataImportRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_metadata_import"]
 
     @property
     def export_metadata(
         self,
-    ) -> Callable[[metastore.ExportMetadataRequest], operations.Operation]:
+    ) -> Callable[[metastore.ExportMetadataRequest], operations_pb2.Operation]:
         r"""Return a callable for the export metadata method over gRPC.
 
         Exports metadata from a service.
@@ -547,14 +520,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["export_metadata"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/ExportMetadata",
                 request_serializer=metastore.ExportMetadataRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["export_metadata"]
 
     @property
     def restore_service(
         self,
-    ) -> Callable[[metastore.RestoreServiceRequest], operations.Operation]:
+    ) -> Callable[[metastore.RestoreServiceRequest], operations_pb2.Operation]:
         r"""Return a callable for the restore service method over gRPC.
 
         Restores a service from a backup.
@@ -573,7 +546,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["restore_service"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/RestoreService",
                 request_serializer=metastore.RestoreServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["restore_service"]
 
@@ -630,7 +603,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     @property
     def create_backup(
         self,
-    ) -> Callable[[metastore.CreateBackupRequest], operations.Operation]:
+    ) -> Callable[[metastore.CreateBackupRequest], operations_pb2.Operation]:
         r"""Return a callable for the create backup method over gRPC.
 
         Creates a new Backup in a given project and location.
@@ -649,14 +622,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["create_backup"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/CreateBackup",
                 request_serializer=metastore.CreateBackupRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_backup"]
 
     @property
     def delete_backup(
         self,
-    ) -> Callable[[metastore.DeleteBackupRequest], operations.Operation]:
+    ) -> Callable[[metastore.DeleteBackupRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete backup method over gRPC.
 
         Deletes a single backup.
@@ -675,7 +648,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             self._stubs["delete_backup"] = self.grpc_channel.unary_unary(
                 "/google.cloud.metastore.v1alpha.DataprocMetastore/DeleteBackup",
                 request_serializer=metastore.DeleteBackupRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_backup"]
 
